Crate bit_buf

Crate bit_buf 

See BitBuf::from(), Storage/StorageMut, and BitBuf::{read,write}_*()

Any usage of pos/offset implies bits rather than bytes

Structs

BitBuf
The main structure

Enums

Error
Error from checked operations

Traits

Storage
This trait must be implemented for types from which you wish to use read_* operations with
StorageMut
This trait must be implemented for types from which you wish to use write_* operations with

Type Aliases

Result
Returned from checked operations