BitBuf

Struct BitBuf 

pub struct BitBuf<S> { /* private fields */ }
The main structure

Keeps track of the data storage and a cursor for automatic operations

Implementations

Source

impl<S> BitBuf<S>

pub const fn from(data: S) -> Self

Construct from provided data storage

pub fn bytes(&self) -> &[u8]
where S: Storage,

Get the underlying bytes from the storage

pub fn bytes_mut(&mut self) -> &mut [u8]
where S: StorageMut,

Get the underlying bytes from the storage

pub fn pos(&self) -> usize

Get the internal cursor for automatic operations

The cursor may not be within storage bounds

pub fn byte_pos(&self) -> usize

Get the byte-aligned position of the internal cursor for automatic operations

The cursor may not be within storage bounds

pub fn advance(&mut self, bits: usize) -> &mut Self

Advance the internal cursor for automatic operations

This does not enforce that the cursor stay within storage bounds

pub fn advance_bytes(&mut self, bytes: usize) -> &mut Self

Advance the internal cursor for automatic operations by a number of bytes

This does not enforce that the cursor stay within storage bounds

pub fn seek(&mut self, offset: usize) -> &mut Self

Set the internal cursor for automatic operations

This does not enforce that the cursor stay within storage bounds

pub fn seek_byte(&mut self, byte: usize) -> &mut Self

Set the internal cursor for automatic operations to a byte position

This sets the cursor to offset * 8 bits.

This does not enforce that the cursor stay within storage bounds

pub fn is_aligned(&self) -> bool

Checks if the internal cursor for automatic operations is aligned on the start of a byte

This does not care whether the cursor is outside storage bounds

Source

impl<S: Storage> BitBuf<S>

pub unsafe fn read_u8_be_aligned_full_at_unchecked( &self, byte_offset: usize, ) -> u8

Read a BE-bit-order u8 from byte_offset without performing bound checks

Safety
Panics
pub unsafe fn read_u8_be_aligned_full_unchecked(&mut self) -> u8

Read the next BE-bit-order u8 without performing bound checks, advancing the internal cursor

Safety
Panics
pub unsafe fn read_u8_be_full_at_unchecked(&self, offset: usize) -> u8

Read a BE-bit-order u8 from offset without performing bound checks

Safety
Panics
pub fn try_read_u8_be_full_at(&self, offset: usize) -> Result<u8>

Read a BE-bit-order u8 from offset while performing bound checks

Errors
pub fn read_u8_be_full_at(&self, offset: usize) -> u8

Read a BE-bit-order u8 from offset, panicking on out of bounds

Panics
Source

impl<S: StorageMut> BitBuf<S>

pub unsafe fn write_u8_be_aligned_full_at_unchecked( &mut self, byte_offset: usize, v: u8, ) -> &mut Self

Write a u8 in BE-bit-order at byte_offset without performing bound checks

Safety
Panics
pub unsafe fn write_u8_be_aligned_full_unchecked(&mut self, v: u8) -> &mut Self

Write a u8 in BE-bit-order without performing bound checks, advancing the internal cursor

Safety
Panics