See BitBuf::from(), Storage/StorageMut, and BitBuf::{read,write}_*()
| Term | Definition |
|---|---|
| UB | Undefined Behaviour |
| BE | Big Endian |
| LE | Little Endian |
Any usage of pos/offset implies bits rather than bytes
Structs
- BitBuf
- The main structure
Enums
- Error
- Error from checked operations
Traits
- Storage
- This trait must be implemented for types from which you wish to use
read_*operations with - Storage
Mut - This trait must be implemented for types from which you wish to use
write_*operations with
Type Aliases
- Result
- Returned from checked operations